"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const sequelize_1 = require("sequelize");
const SqliteProvider_1 = __importDefault(require("../src/database/SqliteProvider"));
const fs_1 = __importDefault(require("fs"));
const Database_1 = require("../src/database/Database");
const PATH_TO_SQLITE_DB_PATH = './db__test__sqlite3';
describe("Database", () => {
    afterEach(() => {
        if (fs_1.default.existsSync(PATH_TO_SQLITE_DB_PATH)) {
            fs_1.default.rmSync(PATH_TO_SQLITE_DB_PATH);
        }
    });
    it("sqlite:memory:create db", () => __awaiter(void 0, void 0, void 0, function* () {
        const provider = new SqliteProvider_1.default();
        let db = (0, Database_1.connectDatabase)(provider);
        let model = db.define('Test', {
            content: sequelize_1.NUMBER
        });
        yield model.sync();
        yield model.create({
            content: 2
        });
        let count = yield model.count();
        (0, chai_1.expect)(count).to.be.eq(1);
        yield db.close();
        db = (0, Database_1.connectDatabase)(provider);
        model = db.define('Test', {
            content: sequelize_1.NUMBER
        });
        yield model.sync();
        count = yield model.count();
        (0, chai_1.expect)(count).to.be.eq(0);
    }));
    it("sqlite:path:create db", () => __awaiter(void 0, void 0, void 0, function* () {
        const provider = new SqliteProvider_1.default(PATH_TO_SQLITE_DB_PATH);
        let db = (0, Database_1.connectDatabase)(provider);
        let model = db.define('Test', {
            content: sequelize_1.NUMBER
        });
        yield model.sync();
        yield model.create({
            content: 2
        });
        let count = yield model.count();
        (0, chai_1.expect)(count).to.be.eq(1);
        yield db.close();
        db = (0, Database_1.connectDatabase)(provider);
        model = db.define('Test', {
            content: sequelize_1.NUMBER
        });
        yield model.sync();
        count = yield model.count();
        (0, chai_1.expect)(count).to.be.eq(1);
    }));
});
